@@ -1,6 +1,7 @@
 import argparse, math, os, sys
 from multiprocessing import TimeoutError as mp_TimeoutError
 from pathlib import Path
+from shutil import which
 from timeit import default_timer as timer
 from typing import Dict, List, Optional
 
@@ -145,6 +146,7 @@ def _add_folder(args, folder_path: Path) -> None:
         "path": str(folder_path),
         "config": utils.filter_namespace(args, ["ocr", "speech_recognition", "scan_subtitles"]),
         "time_deleted": 0,
+        "profile": args.profile,
         "category": category,
         **args.extra_playlist_data,
     }
@@ -249,6 +251,10 @@ def parse_args(action, usage) -> argparse.Namespace:
         args.paths = utils.conform(args.paths)
     log.info(utils.dict_filter_bool(args.__dict__))
 
+    if args.profile in (DBType.audio, DBType.video) and not which("ffprobe"):
+        print("ffmpeg is not installed. Install with your package manager.")
+        raise SystemExit(3)
+
     return args
 
 
@@ -324,5 +330,8 @@ def fs_update(args=None) -> None:
     )
 
     for playlist in playlists:
-        args_env = args if playlist["config"] is None else argparse.Namespace(**{**playlist["config"], **args.__dict__})
+        args_env = argparse.Namespace(
+            **{**(playlist.get("config") or {}), **args.__dict__, "profile": playlist["profile"]}
+        )
+
         extractor(args_env, [playlist["path"]])
