@@ -3,8 +3,6 @@ from pathlib import Path
 from random import random
 from typing import Dict, Tuple
 
-from catt.api import CattDevice
-
 from xklb import consts, db, player, tube_backend, utils
 from xklb.consts import SC
 from xklb.player import get_ordinal_media, mark_media_deleted, override_sort
@@ -51,7 +49,7 @@ def construct_query(args) -> Tuple[str, dict]:
                 args.sort = "random(), " + args.sort
             else:
                 limit = consts.DEFAULT_PLAY_QUEUE * 16
-        if 'limit' not in args.defaults:
+        if "limit" in args.defaults:
             cf.append(f"and rowid in (select rowid from media order by random() limit {limit})")
 
     args.sql_filter = " ".join(cf)
@@ -67,7 +65,7 @@ def construct_query(args) -> Tuple[str, dict]:
         duration = "cast(length(tags) / 4.2 / 220 * 60 as INT) + 10 duration"
 
     cols = args.cols or ["path", "title", duration, "size", "sparseness", "subtitle_count", "is_dir"]
-    SELECT = "\n,".join([c for c in cols if c in m_columns])
+    SELECT = "\n,".join([c for c in cols if c in m_columns or c == "*"])
     LIMIT = "LIMIT " + str(args.limit) if args.limit else ""
     OFFSET = f"OFFSET {args.skip}" if args.skip else ""
     query = f"""SELECT
@@ -430,9 +428,9 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
             args.sort.extend(["sparseness", "size"])
         elif args.action in (SC.listen, SC.watch):
             if "play_count" in columns:
-                args.sort.append("play_count")
+                args.sort.extend(["play_count"])
             if "size" in columns and "duration" in columns:
-                args.sort.append("ntile(1000) over (order by size/duration) desc")
+                args.sort.extend(["priority"])
                 if args.include:
                     args.sort = ["duration desc", "size desc"]
                     if args.print:
@@ -440,8 +438,8 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
 
     if args.play_in_order > 0:
         args.sort.append("path")
+    args.sort = [override_sort(s) for s in args.sort]
     args.sort = ",".join(args.sort).replace(",,", ",")
-    args.sort = override_sort(args.sort)
 
     if args.cols:
         args.cols = list(utils.flatten([s.split(",") for s in args.cols]))
@@ -453,6 +451,8 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
         args.size = parse_size(args)
 
     if args.chromecast:
+        from catt.api import CattDevice
+
         args.cc = CattDevice(args.chromecast_device, lazy=True)
         args.cc_ip = utils.get_ip_of_chromecast(args.chromecast_device)
 
