@@ -57,15 +57,18 @@ def calculate_duration(args, m) -> Tuple[int, int]:
     return start, end
 
 
+def get_browser():
+    default_application = cmd("xdg-mime", "query", "default", "text/html").stdout
+    return which(default_application.replace(".desktop", ""))
+
+
 def find_xdg_application(media_file) -> Optional[str]:
     if media_file.startswith("http"):
-        default_application = cmd("xdg-mime", "query", "default", "text/html").stdout
-    else:
-        mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
-        default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
+        return get_browser()
 
-    player_path = which(default_application.replace(".desktop", ""))
-    return player_path
+    mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
+    default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
+    return which(default_application.replace(".desktop", ""))
 
 
 def parse(args, m=None, media_file=None) -> List[str]:
@@ -274,9 +277,23 @@ def override_sort(sort_expression: str) -> str:
         sort_expression.replace("month_created", YEAR_MONTH("time_created"))
         .replace("month_modified", YEAR_MONTH("time_modified"))
         .replace("random", "random()")
+        .replace("priority", "ntile(1000) over (order by size) desc, duration")
     )
 
 
+def last_chars(candidate):
+    remove_groups = re.split(r"([\W]+|\s+|Ep\d+|x\d+|\.\d+)", candidate)
+    log.debug(remove_groups)
+
+    remove_chars = ""
+    number_of_groups = 1
+    while len(remove_chars) < 1:
+        remove_chars += remove_groups[-number_of_groups]
+        number_of_groups += 1
+
+    return remove_chars
+
+
 def get_ordinal_media(args, path: str) -> str:
     # TODO: maybe try https://dba.stackexchange.com/questions/43415/algorithm-for-finding-the-longest-prefix
 
@@ -286,16 +303,10 @@ def get_ordinal_media(args, path: str) -> str:
     candidate = deepcopy(path)
     similar_videos = []
     while len(similar_videos) < 2:
-        if candidate == '':
+        if candidate == "":
             return path
 
-        remove_groups = re.split(r"([\W]+|\s+|Ep\d+|x\d+|\.\d+)", candidate)
-        log.debug(remove_groups)
-        remove_chars = ""
-        remove_chars_i = 1
-        while len(remove_chars) < 1:
-            remove_chars += remove_groups[-remove_chars_i]
-            remove_chars_i += 1
+        remove_chars = last_chars(candidate)
 
         new_candidate = candidate[: -len(remove_chars)]
         log.debug(f"Matches for '{new_candidate}':")
@@ -312,7 +323,7 @@ def get_ordinal_media(args, path: str) -> str:
             ORDER BY play_count, path
             LIMIT 1000
             """
-        bindings = {"candidate": "%" + candidate + "%"}
+        bindings = {"candidate": candidate + "%"}
         if args.play_in_order == 2:
             if args.include or args.exclude:
                 bindings = {**bindings, "query": args.sql_filter_bindings["query"]}
