@@ -1,4 +1,4 @@
-import argparse, enum, functools, hashlib, logging, math, multiprocessing, os, platform, re, signal, subprocess, sys, textwrap
+import argparse, enum, functools, hashlib, logging, math, multiprocessing, os, platform, re, shutil, signal, subprocess, sys, tempfile, textwrap
 from ast import literal_eval
 from collections.abc import Iterable
 from datetime import datetime, timedelta, timezone
@@ -10,7 +10,6 @@ from typing import Any, Dict, Generator, List, Optional, Union
 import humanize
 from IPython.core import ultratb
 from IPython.terminal.debugger import TerminalPdb
-from pychromecast import discovery
 from rich.logging import RichHandler
 
 from xklb import consts
@@ -168,6 +167,16 @@ def cmd(*command, strict=True, cwd=None, quiet=True, interactive=False, **kwargs
     return r
 
 
+def file_temp_copy(src):
+    fo_dest = tempfile.NamedTemporaryFile(delete=False)
+    with open(src, "r+b") as fo_src:
+        shutil.copyfileobj(fo_src, fo_dest)
+    fo_dest.seek(0)
+    fname = fo_dest.name
+    fo_dest.close()
+    return fname
+
+
 def trash(f: Union[Path, str]) -> None:
     trash_put = which("trash-put") or which("trash")
     if trash_put is not None:
@@ -199,6 +208,8 @@ def remove_text_inside_brackets(text: str, brackets="()[]") -> str:  # thanks @j
 
 
 def get_ip_of_chromecast(device_name):
+    from pychromecast import discovery
+
     cast_infos, browser = discovery.discover_listed_chromecasts(friendly_names=[device_name])
     browser.stop_discovery()
     if not cast_infos:
